﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Threading;
using System.Runtime.InteropServices;
using System.Diagnostics;
using System.IO;

namespace EPT_Oscilloscope
{
    public partial class EPT_Oscilloscope : Form
    {

        int[] StorageArray = new int[50000];
        
        public EPT_Oscilloscope()
        {
            InitializeComponent();

            InitializeStorageArray();

            // reduce flicker

            SetStyle(ControlStyles.UserPaint, true);
            SetStyle(ControlStyles.AllPaintingInWmPaint, true);
            SetStyle(ControlStyles.DoubleBuffer, true);


            for (int i = 0; i < EPTTransmitDevice.Length; ++i)
            {
                EPTTransmitDevice[i] = new Transfer();
            }

            btnTrigger1.BackColor = Color.LightGray;
            btnTrigger2.BackColor = Color.LightGray;
            btnTrigger3.BackColor = Color.LightSteelBlue;
            btnVRef1.BackColor = Color.LightGray;
            btnVRef2.BackColor = Color.LightSteelBlue;
            btnVRef3.BackColor = Color.LightGray;
            btnFifoHoldEn.BackColor = Color.LightGray;
        }

        //Index to store device selection
        Int32 device_index;

        //Create a Receive object of the Transfer Class.
        Transfer EPTReceiveData = new Transfer();

        //Create an array of the Transfer Class for device
        Transfer[] EPTTransmitDevice = new Transfer[8];

        //Parameters
        public const byte TRIGGER_OUT_COMMAND = 0x1;
        public const byte TRANSFER_OUT_COMMAND = 0x2;
        public const byte BLOCK_OUT_COMMAND = 0x4;

        //Value to hold the errors in Block Compares
        public int BlockErrorCount = 0;
        public bool EnableLogFile = false;

        //Buffer to hold bytes returned from EPT-570-AP
        int[] ScopeBuffer = new int[50000];
        public uint EPTReceiveIndex=0;

        //Oscilloscope Data File
        //byte[] HexByte;
        //int GlobalIndex = 0;

        //Flag to prevent BlockOutReceive or TriggerOutRecieve from writing
        // to the ScopeBuffer or initiating RefreshScope() while RefreshScope()
        //is in process
        public bool RefreshBusy = false;

        private bool StorageOn = false;

        //Voltage Scale Factor
        public int VoltageScaleValue = 5;

        //Prescalar value
        public char [] PreScalarValue = new char[10];

        //Voltage Reference value
        public char VoltageReference = '1';

        //Parameters for Voltage Reference Buttons
        public const int SELECT_VREF1 = 1;
        public const int SELECT_VREF2 = 2;
        public const int SELECT_VREF3 = 3;

        //Voltage Reference value
        public char TriggerEvent = '1';

        //Parameters for Voltage Reference Buttons
        public const int SELECT_TRIG1 = 1;
        public const int SELECT_TRIG2 = 2;
        public const int SELECT_TRIG3 = 3;

        //FifoHold register
        public bool FifoHold = false;
        public bool SetFifoHoldEnable = false;

        //Prescalar value
        public char[] TriggerThreshold = new char[10];

        //Counter to hold the number of times the refresh has
        //occurred. When the refresh count is greater than
        //the REFRESH_TIMEOUT, a SetFifoHold() is called for
        //a selected amount of time to allow the Active Host
        //to process pending data
        public uint RefreshCount=0;
        
        //Parameters for the Fifo hold off
        public const int REFRESH_TIMEOUT = 150;
        public const int FIFO_HOLD_TIME = 1200;

        //StreamWrite File
        StreamWriter writer;

        //Save File string
        public string Saved_File;
        public string previousPath = "";

        //Save Data To File Flag
        public bool SaveDataToFile = false;


        // Main object loader
        private void EPT_Oscilloscope_Load(object sender, System.EventArgs e)
        {
            // Call the List Devices function
            ListDevices();

            //Set Debug Mode
            //EPT_AH_SetDebugMode(1);

            //Set the Voltage Scale
            lblVoltScale.Text = "1 Volt\n Per Division";

            //Set Label to blank
            lblDeviceConnected.Text = " ";

            //Set the Horizontal Time Base label
            lblTimeBase.Text = " ";

            //Set the Trigger Voltage label
            lblTriggerVoltage.Text = " ";
        }


        private void SetButtonEnables()
        {
            btnOpenDevice.Enabled = true;
            btnCloseDevice.Enabled = false;

            btnStart.Enabled = true;
            btnStop.Enabled = false;
        }


        private void btnOpenDevice_Click(object sender, EventArgs e)
        {
            //Open the Device
            OpenDevice();
            lblDeviceConnected.Text = "Device Connected";
            btnOpenDevice.Enabled = false;
            btnCloseDevice.Enabled = true;
        }

        private void btnCloseDevice_Click(object sender, EventArgs e)
        {
            if (EPT_AH_CloseDeviceByIndex(device_index) != 0)
            {
            }
            btnOpenDevice.Enabled = true;
            btnCloseDevice.Enabled = false;

        }

        private void btnStart_Click(object sender, EventArgs e)
        {
            EPT_AH_SendTransferControlByte((char)2, (char)1);
            btnStart.Enabled = false;
            btnStop.Enabled = true;
        }

        private void btnStop_Click(object sender, EventArgs e)
        {
            EPT_AH_SendTransferControlByte((char)2, (char)0);
            btnStart.Enabled = true;
            btnStop.Enabled = false;
        }

        private void btnReset_Click(object sender, EventArgs e)
        {
            EPT_AH_SendTransferControlByte((char)2, (char)2);
            Thread.Sleep(1);
            EPT_AH_SendTransferControlByte((char)2, (char)0);

        }

        void InitializeStorageArray()
        {
            for (int i = 0; i < StorageArray.Length; i++)
            {
                StorageArray[i] = 0;
            }
        }

        Random r = new Random();


        private void trkVoltageScale_Scroll(object sender, EventArgs e)
        {
            double VoltageScaleC=0;
            VoltageScaleValue = (int)trkVoltageScale.Value;

            if(VoltageScaleValue >= 5)
               VoltageScaleC =  VoltageScaleValue-4;
            else
               VoltageScaleC = (double)(VoltageScaleValue / 5.0);

            lblVoltScale.Text = VoltageScaleC.ToString() + " Volt\n Per Division";
        }
        
        private void RefreshScope(Graphics g)
        {
            int xmax = 450; // number of sample points
            //int ymax = 225;  // maximum y value
            int ymax = 256;  // maximum y value
            int xlast = -1;
            int ylast = 0;
            int xDraw = 0;
            int yDraw = 0;
            int ScopeIndex = 0;

            int nToggleColor = 0;


            // put the a/d readings into repeat mode for 450 readings
            int n = 0;

            RefreshBusy = true;

            try
            {
                // read each value from the buffer and plot the sample on the scope		
                for (int xpos = 0; xpos < xmax; xpos++)
                {
                    if (StorageOn)
                        n = StorageArray[xpos];
                    else
                        StorageArray[xpos] = n;

                    if(SaveDataToFile)
                        writer.Write("{0:0} ", n);


                    // n between 0 and 1023
                    System.Single y = 0;
                    System.Single volt = 0;
                    int yint = 0;


                    // scale the voltage according to the voltage scale control

                    if (VoltageScaleValue >= 5)
                    {
                        yint = (int)(n / (VoltageScaleValue - 4));
                    }
                    else
                    {
                        yint = (int)(n * (5 - VoltageScaleValue));
                    }

                    // offset the voltage based on the y position dial
                    yint -= -(this.trkVoltageScaleControl.Value);

                    // place the y reading into the correct coordinate system
                    //    by subtracting from the maximum value
                    yDraw = ymax - yint;

                    // don't draw the first sample point, use it as
                    // a starting sample point
                    if (xlast != -1)
                    {
                        // scale the x-value based on the TimeScale control
                        // translate the x-position by the x-position control
                        //xDraw = xpos;
                        //xDraw = xpos * (int)this.TimeScaleControl.Value + ((int)trkTimeScaleControl.Value * (int)TimeScaleControl.Value * 45);
                        xDraw = xpos * (int)this.trkTimeScale.Value + ((int)trkTimeScaleControl.Value * (int)trkTimeScale.Value * 45);

                        // Draw the scaled sample point by connecting
                        // the previous scaled sample point to the current
                        // scaled sample point
                        if (xDraw < kScopeWidth)
                        {
                            if ((nToggleColor % 2 == 0) || (ShowSamplesOn == false))
                                g.DrawLine(Pens.LawnGreen, xlast, ylast, xDraw, yDraw);
                            else
                                g.DrawLine(Pens.Red, xlast, ylast, xDraw, yint);

                        }
                    }

                    // remember the current sample point to allow for connecting
                    // the next sample point
                    xlast = xDraw;
                    ylast = yDraw;

                    nToggleColor++;

                    // read the next a/d value from the buffer
                    if (xpos <= xmax)
                    {
                        if (ScopeIndex < 50000)
                           n = ScopeBuffer[ScopeIndex++];
                    }
                }
                //Set the EPTReceiveIndex to 0 to allow the ScopeBuffer to start
                //adding samples at 0
                EPTReceiveIndex = 0;

                //Reset the ScopBuffer array to zero
                Array.Clear(ScopeBuffer, 0, ScopeBuffer.Length);

                //RefreshBusy is reset to allow the samples to start filling
                //the ScopeBuffer
                RefreshBusy = false;

                if(SetFifoHoldEnable & (RefreshCount++ > REFRESH_TIMEOUT))
                {
                    bool FifoHoldSelect = true;
                    SetFifoHold(FifoHoldSelect);

                    Thread.Sleep(FIFO_HOLD_TIME);

                    FifoHoldSelect = false;
                    SetFifoHold(FifoHoldSelect);

                    RefreshCount = 0;
                }
            }
            catch(Exception ex)
            {
                MessageBox.Show("RefreshScope Error:" + ex);
            }
        }

        const int kScopeWidth = 450;
        const int kScopeHeight = 450;
        Rectangle scopeRect = new Rectangle(0, 0, kScopeWidth, kScopeHeight);

        private void DrawGrid(Graphics g)
        {
            // Draw the Whole screen black
            g.FillRectangle(Brushes.Black, scopeRect);

            const int kpadding = 0;
            const int tickheight = 4;
            const int tickheightLarge = 8;
            // draw the Grid Lines
            for (int i = 0; i < 450; i += 50)
            {
                // draw horizontal line
                g.DrawLine(Pens.DarkGray, 0, i + kpadding, kScopeWidth, i + kpadding);

                // draw vertical line
                g.DrawLine(Pens.DarkGray, i + kpadding, 0, i + kpadding, kScopeHeight);

                // draw ticks on each line
                if (i == 200)
                {
                    for (int j = 0; j < kScopeWidth; j += 5)
                    {
                        if (j % 25 != 0)
                        {
                            g.DrawLine(Pens.White, j, (i - tickheight / 2),
                                j, (i + tickheight / 2));

                            g.DrawLine(Pens.White, (i - tickheight / 2), j,
                                (i + tickheight / 2), j);
                        }
                        else
                        {
                            g.DrawLine(Pens.White, j, (i - tickheightLarge / 2) + kpadding,
                                j, (i + tickheightLarge / 2) + kpadding);

                            g.DrawLine(Pens.White, (i - tickheightLarge / 2), j,
                                (i + tickheightLarge / 2), j);
                        }
                    }
                }
            }


            // Draw Scope from a to d
            if (ScopeOn)
                this.RefreshScope(g);
        }


        private void Form1_Paint(object sender, System.Windows.Forms.PaintEventArgs e)
        {
            Graphics g = e.Graphics;

            try
            {
                // Draw the scope Grid
                DrawGrid(g);
            }
            catch (Exception ex)
            {
                MessageBox.Show("Form1_Paint Error:" + ex);
            }

        }

        bool ScopeOn = false;


        private void button3_Click(object sender, System.EventArgs e)
        {
            // put something on pin 0
            ScopeOn = !ScopeOn;

            if (ScopeOn)
            {
                //Send the Start ADC Conversion command to the Active Transfer Module 2	
                EPT_AH_SendByte(0x02, 's');

                //Send Trigger 1 to latch the ADC Conversion command
                EPT_AH_SendTrigger((byte)0x01);

                button3.BackColor = Color.LightGreen;
                button3.Text = "On";
            }
            else
            {
                //Send the Start ADC Conversion command to the Active Transfer Module 2	
                EPT_AH_SendByte(0x02, 'S');

                //Send Trigger 1 to latch the ADC Conversion command
                EPT_AH_SendTrigger((byte)0x01);

                button3.BackColor = Color.Gray;
                button3.Text = "Off";
            }

            trkTimeBase_Scroll(sender, e);

        }

        private bool ShowSamplesOn = false;
        private void ShowSampleCheck_CheckedChanged(object sender, System.EventArgs e)
        {
            ShowSamplesOn = this.ShowSampleCheck.Checked;
        }


        private void EPTParseReceive()
        {
            try
            {

                switch (EPTReceiveData.Command)
                {
                    case TRIGGER_OUT_COMMAND:
                        TriggerOutReceive();
                        break;
                    case BLOCK_OUT_COMMAND:
                        BLockOutReceive();
                        break;
                    default:
                        break;
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("EPTReceiveIndex = " + EPTReceiveIndex + "EPTParseReceive Error:" + ex);
            }

        }


        public void BLockOutReceive()
        {
            try
            {
            if (!RefreshBusy)
            {
                //EPTTransmitDevice[EPTReceiveData.Address].TransferPending = false;
                // BlockCount = BlockCount + EPTReceiveData.Length;
                foreach (byte b in EPTReceiveData.cBlockBuf)
                {
                    if (EPTReceiveIndex < 5600 )
                    {
                       ScopeBuffer[EPTReceiveIndex++] = (int)b;
                       //HexByte[GlobalIndex++]  = b;
                   }

                }
                //HexByte[GlobalIndex++] = 0x0a;
            }
            }
            catch (Exception ex)
            {
                MessageBox.Show("EPTReceiveIndex = " + EPTReceiveIndex + "EPTParseReceive Error:" + ex);
            }

        }


        public void TriggerOutReceive()
        {
            try
            {
            if (!RefreshBusy)
            {
                switch ((int)EPTReceiveData.Payload)
                {
                    case 0x04:
                        Invalidate();
                        break;

                    default:
                        break;
                }
            }
            }
            catch (Exception ex)
            {
                MessageBox.Show("EPTReceiveIndex = " + EPTReceiveIndex + "EPTParseReceive Error:" + ex);
            }

        }


        private void StorageButton_Click(object sender, EventArgs e)
        {
            StorageOn = !StorageOn;

            if (StorageOn == false)
            {
                StorageButton.ForeColor = Color.Black;
            }
            else
            {
                StorageButton.ForeColor = Color.Red;
            }
        }

        private void btnFifoHoldEn_Click(object sender, EventArgs e)
        {
            SetFifoHoldEnable = !SetFifoHoldEnable;

            if(!SetFifoHoldEnable)
                btnFifoHoldEn.BackColor = Color.LightGray;
            else
                btnFifoHoldEn.BackColor = Color.LightSteelBlue;
        }

        private void btnFifoHold_Click(object sender, EventArgs e)
        {
            FifoHold = !FifoHold;
            SetFifoHold(FifoHold);
        }

        public void SetFifoHold(bool FifoHoldSelection)
        {
            if (FifoHoldSelection)
                EPT_AH_SendTransferControlByte((char)2, (char)5);
            else
                EPT_AH_SendTransferControlByte((char)2, (char)1);
        }

        private void trkTimeBase_Scroll(object sender, EventArgs e)
        {
            //Determine the Prescalar value from the track bar
            switch ((int)trkTimeBase.Value)
            {
                case 1:
                    PreScalarValue[0] = '1';
                    PreScalarValue[1] = '2';
                    PreScalarValue[2] = '8';
                    lblTimeBase.Text = "5.2 milliseconds";
                    break;
                case 2:
                    PreScalarValue[0] = '0';
                    PreScalarValue[1] = '6';
                    PreScalarValue[2] = '4';
                    lblTimeBase.Text = "2.6 milliseconds";
                    break;
                case 3:
                    PreScalarValue[0] = '0';
                    PreScalarValue[1] = '3';
                    PreScalarValue[2] = '2';
                    lblTimeBase.Text = "1.3 milliseconds";
                    break;
                case 4:
                    PreScalarValue[0] = '0';
                    PreScalarValue[1] = '1';
                    PreScalarValue[2] = '6';
                    lblTimeBase.Text = "650 microseconds";
                    break;
                case 5:
                    PreScalarValue[0] = '0';
                    PreScalarValue[1] = '0';
                    PreScalarValue[2] = '8';
                    lblTimeBase.Text = "325 microseconds";
                    break;
                case 6:
                    PreScalarValue[0] = '0';
                    PreScalarValue[1] = '0';
                    PreScalarValue[2] = '4';
                    lblTimeBase.Text = "162 microseconds";
                    break;
                case 7:
                    PreScalarValue[0] = '0';
                    PreScalarValue[1] = '0';
                    PreScalarValue[2] = '2';
                    lblTimeBase.Text = "81 microseconds";
                    break;
                default:
                    break;
            }
            

            //Send the Set PreScalar command to the Active Transfer Module 2	
            EPT_AH_SendByte(0x02, 'P');

            //Send Trigger 1 to latch the ADC Conversion command
            EPT_AH_SendTrigger((byte)0x01);

            Thread.Sleep(1);

            //Send the Set PreScalar Value to the Active Transfer Module 2	
            EPT_AH_SendByte(0x02, PreScalarValue[0]);

            //Send Trigger 1 to latch the ADC Conversion command
            EPT_AH_SendTrigger((byte)0x01);

            EPT_AH_SendByte(0x02, PreScalarValue[1]);

            //Send Trigger 1 to latch the ADC Conversion command
            EPT_AH_SendTrigger((byte)0x01);

            EPT_AH_SendByte(0x02, PreScalarValue[2]);

            //Send Trigger 1 to latch the ADC Conversion command
            EPT_AH_SendTrigger((byte)0x01);

        }

        private void btnVRef1_Click(object sender, EventArgs e)
        {
            //Set the Voltage Referenct to AREF, Internal Vref turned off
            //Set the Voltage Reference value 
            VoltageReference = '0';

            //Send Voltage Reference to Active EndTerm 2
            SetVoltageReference(VoltageReference);

            //Set the Button State so User can know which VoltageReference is selected
            SetVRefControlButtons(SELECT_VREF1);

        }

        private void btnVRef2_Click(object sender, EventArgs e)
        {
            //Set the Voltage Referenct to AVCC with external capacitor at AREF pin
            //Set the Voltage Reference value 
            VoltageReference = '1';

            //Send Voltage Reference to Active EndTerm 2
            SetVoltageReference(VoltageReference);

            //Set the Button State so User can know which VoltageReference is selected
            SetVRefControlButtons(SELECT_VREF2);
        }

        private void btnVRef3_Click(object sender, EventArgs e)
        {
            //Set the Voltage Referenct to Internal 1.1V Voltage Reference with external
            //capacitor at AREF pin
            //Set the Voltage Reference value 
            VoltageReference = '2';

            //Send Voltage Reference to Active EndTerm 2
            SetVoltageReference(VoltageReference);

            //Set the Button State so User can know which VoltageReference is selected
            SetVRefControlButtons(SELECT_VREF3);
        }

        public void SetVoltageReference(char VoltageReference)
        {
            //Send the Set VoltageReference command to the Active Transfer Module 2	
            EPT_AH_SendByte(0x02, 'R');

            //Send Trigger 1 to latch the ADC Conversion command
            EPT_AH_SendTrigger((byte)0x01);

            Thread.Sleep(1);

            //Send the Set VoltageReference Value to the Active Transfer Module 2	
            EPT_AH_SendByte(0x02, VoltageReference);

            //Send Trigger 1 to latch the ADC Conversion command
            EPT_AH_SendTrigger((byte)0x01);
        }

        public void SetVRefControlButtons(int FuncSelect)
        {
            switch (FuncSelect)
            {
                case SELECT_VREF1:
                    btnVRef1.BackColor = Color.LightSteelBlue;
                    btnVRef2.BackColor = Color.LightGray;
                    btnVRef3.BackColor = Color.LightGray;
                   break;
                case SELECT_VREF2:
                   btnVRef1.BackColor = Color.LightGray;
                   btnVRef2.BackColor = Color.LightSteelBlue;
                   btnVRef3.BackColor = Color.LightGray;
                    break;
                case SELECT_VREF3:
                    btnVRef1.BackColor = Color.LightGray;
                    btnVRef2.BackColor = Color.LightGray;
                    btnVRef3.BackColor = Color.LightSteelBlue;
                    break;
                default:
                    btnVRef1.BackColor = Color.LightGray;
                    btnVRef2.BackColor = Color.LightGray;
                    btnVRef3.BackColor = Color.LightGray;
                    break;
            }

            btnVRef1.FlatStyle = FlatStyle.Standard;
            btnVRef2.FlatStyle = FlatStyle.Standard;
            btnVRef3.FlatStyle = FlatStyle.Standard;
        }

        private void btnTrigger1_Click(object sender, EventArgs e)
        {
            //Set the Trigger Event to Toggle
            //Set the Trigger Event value 
            TriggerEvent = '0';

            //Send Trigger Event to Active EndTerm 2
            SetTriggerEvent(TriggerEvent);

            //Set the Button State so User can know which VoltageReference is selected
            SetTriggerControlButtons(SELECT_TRIG1);
        }

        private void btnTrigger2_Click(object sender, EventArgs e)
        {
            //Set the Trigger Event to Falling Edge
            //Set the Trigger Event value 
            TriggerEvent = '2';

            //Send Trigger Event to Active EndTerm 2
            SetTriggerEvent(TriggerEvent);

            //Set the Button State so User can know which VoltageReference is selected
            SetTriggerControlButtons(SELECT_TRIG2);
        }

        private void btnTrigger3_Click(object sender, EventArgs e)
        {
            //Set the Trigger Event to Rising Edge
            //Set the Trigger Event value 
            TriggerEvent = '3';

            //Send Trigger Event to Active EndTerm 2
            SetTriggerEvent(TriggerEvent);

            //Set the Button State so User can know which VoltageReference is selected
            SetTriggerControlButtons(SELECT_TRIG3);
        }


        public void SetTriggerEvent(char TriggerEvent)
        {
            //Send the Set VoltageReference command to the Active Transfer Module 2	
            EPT_AH_SendByte(0x02, 'E');

            //Send Trigger 1 to latch the ADC Conversion command
            EPT_AH_SendTrigger((byte)0x01);

            Thread.Sleep(1);

            //Send the Set VoltageReference Value to the Active Transfer Module 2	
            EPT_AH_SendByte(0x02, TriggerEvent);

            //Send Trigger 1 to latch the ADC Conversion command
            EPT_AH_SendTrigger((byte)0x01);
        }

        public void SetTriggerControlButtons(int FuncSelect)
        {
            switch (FuncSelect)
            {
                case SELECT_TRIG1:
                    btnTrigger1.BackColor = Color.LightSteelBlue;
                    btnTrigger2.BackColor = Color.LightGray;
                    btnTrigger3.BackColor = Color.LightGray;
                    break;
                case SELECT_TRIG2:
                    btnTrigger1.BackColor = Color.LightGray;
                    btnTrigger2.BackColor = Color.LightSteelBlue;
                    btnTrigger3.BackColor = Color.LightGray;
                    break;
                case SELECT_TRIG3:
                    btnTrigger1.BackColor = Color.LightGray;
                    btnTrigger2.BackColor = Color.LightGray;
                    btnTrigger3.BackColor = Color.LightSteelBlue;
                    break;
                default:
                    btnTrigger1.BackColor = Color.LightGray;
                    btnTrigger2.BackColor = Color.LightGray;
                    btnTrigger3.BackColor = Color.LightGray;
                    break;
            }

            btnTrigger1.FlatStyle = FlatStyle.Standard;
            btnTrigger2.FlatStyle = FlatStyle.Standard;
            btnTrigger3.FlatStyle = FlatStyle.Standard;
        }

        private void trkTriggerValue_Scroll(object sender, EventArgs e)
        {

            switch (trkTriggerValue.Value)
            {
                case 1:
                    TriggerThreshold[0] = '0';
                    TriggerThreshold[1] = '5';
                    TriggerThreshold[2] = '1';
                    lblTriggerVoltage.Text = "1 Volt";
                    break;
                case 2:
                    TriggerThreshold[0] = '1';
                    TriggerThreshold[1] = '0';
                    TriggerThreshold[2] = '2';
                    lblTriggerVoltage.Text = "2 Volts";
                    break;
                case 3:
                    TriggerThreshold[0] = '1';
                    TriggerThreshold[1] = '5';
                    TriggerThreshold[2] = '3';
                    lblTriggerVoltage.Text = "3 Volts";
                    break;
                case 4:
                    TriggerThreshold[0] = '2';
                    TriggerThreshold[1] = '0';
                    TriggerThreshold[2] = '4';
                    lblTriggerVoltage.Text = "4 Volts";
                    break;
                case 5:
                    TriggerThreshold[0] = '2';
                    TriggerThreshold[1] = '5';
                    TriggerThreshold[2] = '5';
                    lblTriggerVoltage.Text = "5 Volts";
                    break;
                default:
                    break;
            }



            //Send the Set PreScalar command to the Active Transfer Module 2	
            EPT_AH_SendByte(0x02, 'T');

            //Send Trigger 1 to latch the ADC Conversion command
            EPT_AH_SendTrigger((byte)0x01);

            Thread.Sleep(1);

            //Send the Set PreScalar Value to the Active Transfer Module 2	
            EPT_AH_SendByte(0x02, TriggerThreshold[0]);

            //Send Trigger 1 to latch the ADC Conversion command
            EPT_AH_SendTrigger((byte)0x01);

            EPT_AH_SendByte(0x02, TriggerThreshold[1]);

            //Send Trigger 1 to latch the ADC Conversion command
            EPT_AH_SendTrigger((byte)0x01);

            EPT_AH_SendByte(0x02, TriggerThreshold[2]);

            //Send Trigger 1 to latch the ADC Conversion command
            EPT_AH_SendTrigger((byte)0x01);


        }

        private void mnuSave_Click(object sender, EventArgs e)
        {
            Saved_File = "";
            saveFD.InitialDirectory = previousPath;
            saveFD.Title = "Save an Oscilloscope File";
            saveFD.FileName = "";

            saveFD.Filter = "Oscilloscope Files|*.osc";
            saveFD.RestoreDirectory = true;
            if (saveFD.ShowDialog() != DialogResult.Cancel)
            {
                previousPath = Path.GetDirectoryName(saveFD.FileName);
                Saved_File = saveFD.FileName;
            }
            else
                return;

            // Open a file
            //Stream stream = File.Open(Saved_File, FileMode.Create);

            writer = new StreamWriter(Saved_File);

            writer.Write("Oscilloscope File");

            //Set a flag to indicate all data will be saved a file
            SaveDataToFile = true;


            //stream.Close();
        }





    }

    public class Transfer
    {
        public int Command;
        public int Address;
        public int Length;
        public int Payload;
        public byte[] cBlockBuf;
        public bool TransferPending;
        public uint Repititions;

        public Transfer()
        {
            Command = 0;
            Address = 0;
            Length = 0;
            Payload = 0;
            TransferPending = false;
            Repititions = 0;
        }

    }

}
